scoretools.move_full_measure_tuplet_prolation_to_measure_time_signature
=======================================================================

.. autofunction:: abjad.tools.scoretools.move_full_measure_tuplet_prolation_to_measure_time_signature.move_full_measure_tuplet_prolation_to_measure_time_signature
